@@ -2,11 +2,11 @@ use 5.008;
 use strict;
 use warnings;
 package BenchmarkAnything::Storage::Frontend::HTTP;
-# git description: v0.010-2-ga53a505
+# git description: v0.011-5-g99b1f16
 
 our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Access a BenchmarkAnything store via HTTP
-$BenchmarkAnything::Storage::Frontend::HTTP::VERSION = '0.011';
+$BenchmarkAnything::Storage::Frontend::HTTP::VERSION = '0.012';
 use Mojo::Base 'Mojolicious';
 
 require File::HomeDir; # MUST 'require', 'use' conflicts with Mojolicious
@@ -22,7 +22,9 @@ has balib => sub
         my $self = shift;
 
         require BenchmarkAnything::Storage::Frontend::Lib;
-        return BenchmarkAnything::Storage::Frontend::Lib->new;
+        my $balib = BenchmarkAnything::Storage::Frontend::Lib->new(cfgfile => $self->app->bacfg->{cfgfile});
+        $self->log->debug(" - balib.cfgfile: ".$balib->{cfgfile});
+        return $balib;
 };
 
 has backend => sub
@@ -30,7 +32,18 @@ has backend => sub
         my $self = shift;
 
         require BenchmarkAnything::Storage::Backend::SQL;
-        return BenchmarkAnything::Storage::Backend::SQL->new ({ dbh => $self->app->balib->{dbh}, debug => 0 });
+        my $bacfg = $self->app->bacfg;
+
+        my $searchengine = $bacfg->{benchmarkanything}{searchengine} || {};
+        my $dbh_config   = $bacfg->{benchmarkanything}{storage}{backend}{sql} || {};
+
+        return BenchmarkAnything::Storage::Backend::SQL->new ({ dbh => $self->app->balib->{dbh},
+                                                                dbh_config => $dbh_config,
+                                                                debug => $bacfg->{benchmarkanything}{debug},
+                                                                force => $bacfg->{benchmarkanything}{force},
+                                                                verbose => $bacfg->{benchmarkanything}{verbose},
+                                                                (keys %$searchengine ? (searchengine => $searchengine) : ()),
+                                                              });
 };
 
 
@@ -59,21 +72,25 @@ sub startup {
         my $queueing_processing_sleep      = $self->app->bacfg->{benchmarkanything}{storage}{backend}{sql}{queueing}{processing_sleep}      ||  30;
         my $queueing_gc_sleep              = $self->app->bacfg->{benchmarkanything}{storage}{backend}{sql}{queueing}{gc_sleep}              || 120;
 
-        $self->log->debug(" - Q.batch_size: $queueing_processing_batch_size");
-        $self->log->debug(" - Q.sleep:      $queueing_processing_sleep");
-        $self->log->debug(" - Q.gc_sleep:   $queueing_gc_sleep");
+        my $disable_process_benchmarkanything_queue = $self->app->bacfg->{benchmarkanything}{storage}{frontend}{http}{disable_process_benchmarkanything_queue} || 0;
+
+        $self->log->debug(" - Q.batch_size:         $queueing_processing_batch_size");
+        $self->log->debug(" - Q.sleep:              $queueing_processing_sleep");
+        $self->log->debug(" - Q.gc_sleep:           $queueing_gc_sleep");
+        $self->log->debug(" - Q.disable_processing: $disable_process_benchmarkanything_queue");
 
         $self->plugin('InstallablePaths');
 
         # recurring worker
         Mojo::IOLoop->recurring($queueing_processing_sleep => sub {
+                                        sleep(rand($queueing_processing_sleep));
                                         $self->log->debug("process bench queue (batchsize: $queueing_processing_batch_size) [".~~localtime."]");
                                         $self->app->balib->process_raw_result_queue($queueing_processing_batch_size);
-                                });
+                                }) unless $disable_process_benchmarkanything_queue;
         Mojo::IOLoop->recurring($queueing_gc_sleep => sub {
                                         $self->log->debug("garbage collection [".~~localtime."]");
                                         $self->app->balib->gc();
-                                });
+                                }) unless $disable_process_benchmarkanything_queue;
 
         # routes
         my $routes = $self->routes;
@@ -115,7 +132,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Steffen Schwigon.
+This software is copyright (c) 2018 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
